@@ -34,7 +34,7 @@ def main():
         logging.basicConfig(level=args.verbose)
 
     logging.debug("Reading file %s for messages", args.filename)
-    with open(args.filename) as f:
+    with open(args.filename, encoding="utf8") as f:
         lines = f.readlines()
 
     messages = list(parse_messages(lines))
