@@ -1,6 +1,5 @@
 import logging
 
-from wordleparse.parser import MessageParser, is_new_message_line
 from wordleparse.parsers import (
     wordle_parser,
     woordle_parser,
@@ -62,11 +61,10 @@ def print_result(game, messages):
     printer = [p for p in result_printers if p.game == game]
     try:
         printer = [p for p in result_printers if p.game == game][0]
-    except IndexError:
+    except IndexError as e:
         raise ValueError(
             f"No valid printer found for game {game}. Known printers are {result_printers}"
-        )
-        return
+        ) from e
 
     max_person_length = max([len(p) for p in {m.person for m in messages}])
     printer.print(messages, ljust=max_person_length)
