@@ -1,7 +1,7 @@
 import re
 import emoji
 
-from wordleparse.parser import MessageParser, CustomParser
+from wordleparse.parser import MessageParser
 from wordleparse.errors import UnparsableError
 
 
