@@ -1,5 +1,5 @@
 import re
-from typing import List
+from typing import List, Callable
 
 from wordleparse.message import Message
 
@@ -7,7 +7,8 @@ from wordleparse.message import Message
 DEFAULT_SCORE = r"(?P<score>[0-9X]+)/[0-9]+"
 
 
-def _default_print(person: str, messages: List[Message], ljust: int) -> None:
+def default_print(messages: List[Message], ljust: int, fn: Callable = print) -> None:
+    person = extract_person(messages)
     scores = [re.match(DEFAULT_SCORE, m.score).group("score") for m in messages]
     fails = len([s for s in scores if s == "X"])
     success = [int(s) for s in scores if s != "X"]
@@ -16,16 +17,24 @@ def _default_print(person: str, messages: List[Message], ljust: int) -> None:
         if len(success) > 0
         else "No average score "
     )
-    print(
+    fn(
         f"{person.ljust(ljust)}: {len(messages)} games, "
         + f"{fails} failed attempts ({fails / len(messages):.1%}). "
         + avg_score
-        + f"for the completed games."
+        + "for the completed games."
     )
 
 
+def extract_person(messages: List[Message]) -> str:
+    persons = {m.person for m in messages}
+    if len(persons) > 1:
+        raise ValueError("Should only print messages of one person")
+
+    return persons.pop()
+
+
 class GamePrinter:
-    def __init__(self, game: str, print_fn=_default_print):
+    def __init__(self, game: str, print_fn=default_print):
         self.game = game
         self.print_fn = print_fn
 
@@ -34,7 +43,7 @@ class GamePrinter:
         persons = {m.person for m in messages}
         for person in sorted(persons):
             person_messages = [m for m in messages if m.person == person]
-            self.print_fn(person, person_messages, ljust)
+            self.print_fn(person_messages, ljust)
 
         print("=====================\n")
 
