@@ -12,10 +12,10 @@ def group(lines: Iterator[str]) -> Iterator[List[str]]:
     """
     try:
         line = next(lines)
-    except StopIteration:
+    except StopIteration as e:
         raise ValueError(
             "We couldn't find the first message. Is the chat export empty?"
-        )
+        ) from e
 
     while lines:
         message = [line]
